@@ -85,10 +85,8 @@ class PartialCCA(MCCA):
                 f"partial CCA."
             )
         check_is_fitted(self, attributes=["weights"])
-        views = _check_views(
-            *views, copy=self.copy_data, accept_sparse=self.accept_sparse
-        )
-        views = self._centre_scale_transform(views)
+        _check_views(views)
+        views = [self.scalers[i].transform(view) for i, view in enumerate(views)]
         transformed_views = []
         for i, (view) in enumerate(views):
             transformed_view = (
