@@ -1,11 +1,9 @@
 from ._eigengame import PLSEigenGame, CCAEigenGame, RCCAEigenGame
 from ._ghagep import PLSGHAGEP, CCAGHAGEP, RCCAGHAGEP
-from ._incrementalpls import IncrementalPLS
-from ._stochasticpls import PLSStochasticPower
+#from ._stochasticpls import PLSStochasticPower
 
 __all__ = [
-    "IncrementalPLS",
-    "PLSStochasticPower",
+    #"PLSStochasticPower",
     "PLSGHAGEP",
     "CCAGHAGEP",
     "RCCAGHAGEP",
