@@ -73,7 +73,7 @@ class RCCAEigenGame(_BaseStochastic):
         timeout=0,
         worker_init_fn=None,
         epochs=1,
-        learning_rate=None,
+        learning_rate=1,
         initialization: Union[str, callable] = "random",
         c=0,
         nesterov=True,
@@ -123,20 +123,19 @@ class RCCAEigenGame(_BaseStochastic):
     def _split_weights(self, views, weights):
         splits = np.cumsum([0] + [view.shape[1] for view in views])
         weights = [
-            weights[split: splits[i + 1]]
-            for i, split in enumerate(splits[:-1])
+            weights[split : splits[i + 1]] for i, split in enumerate(splits[:-1])
         ]
         return weights
 
     def _update(self, views):
-        #combine weights
+        # combine weights
         self.weights = np.vstack(self.weights)
         if self.component_wise:
             for k in range(self.weights.shape[1]):
                 self._update_component(views, k=k)
         else:
             self._update_all(views)
-        #split weights
+        # split weights
         self.weights = self._split_weights(views, self.weights)
 
     def _update_all(self, views):
@@ -152,14 +151,10 @@ class RCCAEigenGame(_BaseStochastic):
         grads = self.grads(views, u=self.y)
         if self.line_search:
             self.learning_rate = self._backtracking_line_search(views)
-            t = self.learning_rate
-        else:
-            t = self.learning_rate
+        t = self.learning_rate
         self.u = self._gradient_step(self.y, t, grads)
         if self.ensure_descent:
-            if self.objective(views, u=self.u) < self.objective(
-                    views, u=self.weights
-            ):
+            if self.objective(views, u=self.u) < self.objective(views, u=self.weights):
                 self.weights = self.u.copy()
         else:
             self.weights = self.u.copy()
@@ -172,19 +167,19 @@ class RCCAEigenGame(_BaseStochastic):
             if self.u is None:
                 self.u = self.weights.copy()
             self.y[:, k] = self.weights[:, k] + self.momentum * (
-                    self.u[:, k] - self.weights[:, k]
+                self.u[:, k] - self.weights[:, k]
             )
         else:
             self.y[:, k] = self.weights[:, k].copy()
         grads = self.grads(views, u=self.y)
         if self.line_search:
-            t = self._backtracking_line_search(views, k=k)
+            t=self._backtracking_line_search(views, k=k)
         else:
             t = self.learning_rate
-        self.u[:, k] =  self._gradient_step(self.y[:,k], t, grads[:,k])
+        self.u[:, k] = self._gradient_step(self.y[:, k], t, grads[:, k])
         if self.ensure_descent:
             if self.objective(views, u=self.u, k=k) < self.objective(
-                    views, u=self.weights, k=k
+                views, u=self.weights, k=k
             ):
                 self.weights[:, k] = self.u[:, k].copy()
         else:
@@ -209,41 +204,57 @@ class RCCAEigenGame(_BaseStochastic):
             if k is None:
                 updated_solution = self._gradient_step(self.y, step_size, gradient)
             else:
-                updated_solution[:, k] = self.y[:, k] - step_size * gradient
+                updated_solution[:, k] = self._gradient_step(
+                    self.y[:, k], step_size, gradient
+                )
 
             # Check if the objective function decreases with the updated solution
-            if self.objective(views, u=updated_solution, k=k) < self.objective(views, u=self.y, k=k):
+            if (
+                self.objective(views, u=updated_solution, k=k)
+                < self.objective(views, u=self.y, k=k)
+                - 0.5 * step_size * np.linalg.norm(gradient) ** 2
+            ):
                 break
 
             # Reduce the step size by a factor of beta
             step_size *= beta
 
             # Set a lower bound for the step size to avoid numerical issues
-            if step_size < 1e-5:
-                step_size = 1e-5
+            if step_size < 1e-6:
+                step_size = 1e-6
                 break
 
         return step_size
 
     def grads(self, views, u=None):
         Aw, Bw, wAw, wBw = self._get_terms(views, u)
-        grads = 2 * Aw - (Aw @ np.triu(wBw) + Bw @ np.triu(wAw))
+        grads = 2 * Aw - (Aw @ np.triu(wBw) * np.sign(np.diag(wAw)) + Bw @ np.triu(wAw))
+        # TODO: work out why this works
+        # =2 * Aw - (Aw @ np.triu(wBw) + Bw @ np.triu(wAw)) for some reason multiplying by the sign fixes the negative eigenvalue problem here. Not sure why this is the case.
         return -grads
 
     def _Aw(self, views, projections):
-        n=len(views)
-        Aw=np.vstack([view.T @ projections.sum(axis=0) / (n-1) for view in views])-np.vstack([view.T @ projection / (n-1) for view, projection in zip(views,projections)])
-        return Aw
+        Aw = np.vstack(
+            [
+                view.T @ projections.sum(axis=0) / projections[0].shape[0]
+                for view in views
+            ]
+        )
+        return Aw / len(views)
 
     def _Bw(self, views, projections, u):
         weights = self._split_weights(views, u)
         Bw = []
-        for i, (view, projection, weight, c) in enumerate(zip(views, projections, weights, self.c)):
+        for i, (view, projection, weight, c) in enumerate(
+            zip(views, projections, weights, self.c)
+        ):
             if c == 1:
-                Bw.append( c * weight)
+                Bw.append(c * weight)
             else:
-                Bw.append(  (c * weight) + (1 - c) * (view.T @ projection) / projection.shape[0])
-        return np.vstack(Bw)
+                Bw.append(
+                    (c * weight) + (1 - c) * (view.T @ projection) / projection.shape[0]
+                )
+        return np.vstack(Bw) / len(views)
 
     def _get_terms(self, views, u, projections=None):
         if projections is None:
@@ -252,8 +263,6 @@ class RCCAEigenGame(_BaseStochastic):
         Bw = self._Bw(views, projections, u)
         wAw = u.T @ Aw
         wBw = u.T @ Bw
-        wAw[np.diag_indices_from(wAw)] = np.where(np.diag(wAw) > 0, np.diag(wAw), 0)
-        wBw[np.diag_indices_from(wBw)] = np.where(np.diag(wAw) > 0, np.diag(wBw), 0)
         return Aw, Bw, wAw, wBw
 
     def objective(self, views, u=None, k=None, projections=None):
@@ -349,7 +358,7 @@ class CCAEigenGame(RCCAEigenGame):
         timeout=0,
         worker_init_fn=None,
         epochs=1,
-        learning_rate=None,
+        learning_rate=1,
         nesterov=True,
         line_search=False,
         rho=0.1,
@@ -449,12 +458,12 @@ class PLSEigenGame(RCCAEigenGame):
         timeout=0,
         worker_init_fn=None,
         epochs=1,
-        learning_rate=None,
+        learning_rate=1,
         nesterov=True,
         line_search=False,
         rho=0.1,
         ensure_descent=False,
-            component_wise=False,
+        component_wise=False,
     ):
         super().__init__(
             latent_dims=latent_dims,
@@ -482,3 +491,17 @@ class PLSEigenGame(RCCAEigenGame):
             ensure_descent=ensure_descent,
             component_wise=component_wise,
         )
+
+    def _Aw(self, views, projections):
+        Aw = np.vstack(
+            [
+                view.T @ projections.sum(axis=0) / projections[0].shape[0]
+                for view in views
+            ]
+        ) - np.vstack(
+            [
+                view.T @ projection / projections[0].shape[0]
+                for view, projection in zip(views, projections)
+            ]
+        )
+        return Aw / len(views)
