@@ -70,13 +70,13 @@ class RCCAGHAGEP(RCCAEigenGame):
         timeout=0,
         worker_init_fn=None,
         epochs=1,
-        learning_rate=None,
+        learning_rate=1,
         c=0,
         nesterov=True,
         line_search=False,
         rho=0.1,
         ensure_descent=False,
-            component_wise=False,
+        component_wise=False,
     ):
         super().__init__(
             latent_dims=latent_dims,
@@ -109,6 +109,7 @@ class RCCAGHAGEP(RCCAEigenGame):
         Aw, Bw, wAw, wBw = self._get_terms(views, u)
         return -Aw + Bw @ np.triu(wAw)
 
+
 class CCAGHAGEP(RCCAGHAGEP):
     """
     A class used to fit CCA by GHA-GEP
@@ -174,12 +175,12 @@ class CCAGHAGEP(RCCAGHAGEP):
         timeout=0,
         worker_init_fn=None,
         epochs=1,
-        learning_rate=None,
+        learning_rate=1,
         nesterov=True,
         line_search=False,
         rho=0.1,
         ensure_descent=False,
-            component_wise=False,
+        component_wise=False,
     ):
         super().__init__(
             latent_dims=latent_dims,
@@ -274,12 +275,12 @@ class PLSGHAGEP(RCCAGHAGEP):
         timeout=0,
         worker_init_fn=None,
         epochs=1,
-        learning_rate=None,
+        learning_rate=1,
         nesterov=True,
         line_search=True,
         rho=0.1,
         ensure_descent=True,
-            component_wise=False,
+        component_wise=False,
     ):
         super().__init__(
             latent_dims=latent_dims,
@@ -307,3 +308,17 @@ class PLSGHAGEP(RCCAGHAGEP):
             ensure_descent=ensure_descent,
             component_wise=component_wise,
         )
+
+    def _Aw(self, views, projections):
+        Aw = np.vstack(
+            [
+                view.T @ projections.sum(axis=0) / projections[0].shape[0]
+                for view in views
+            ]
+        ) - np.vstack(
+            [
+                view.T @ projection / projections[0].shape[0]
+                for view, projection in zip(views, projections)
+            ]
+        )
+        return Aw / len(views)
